@@ -2,14 +2,16 @@
 // Copyright (c) 2014-2015, Kang Seonghoon.
 // See README.md and LICENSE.txt for details.
 
-#![feature(core, old_io, old_path, collections)] // lib stability features as per RFC #507
+#![feature(core, collections)] // lib stability features as per RFC #507
 
 extern crate core;
 extern crate encoding;
 extern crate getopts;
 
-use std::old_io as io;
-use std::env;
+use std::{io, env};
+use std::io::{Read, Write};
+use std::fs::File;
+use std::path::Path;
 use encoding::{EncoderTrap, DecoderTrap};
 use encoding::label::encoding_from_whatwg_label;
 use getopts::Options;
@@ -65,16 +67,24 @@ fn main() {
     };
 
     let mut input = match matches.free.first().map(|s| &s[..]) {
-        Some("-") | None => Box::new(io::stdin()) as Box<Reader>,
-        Some(f) => Box::new(io::File::open(&Path::new(f))) as Box<Reader>,
+        Some("-") | None => Box::new(io::stdin()) as Box<Read>,
+        Some(f) => match File::open(&Path::new(f)) {
+            Ok(f) => Box::new(f) as Box<Read>,
+            Err(e) => panic!("cannot open the input {}: {}", f, e),
+        },
     };
     let mut output = match matches.opt_str("o").as_ref().map(|s| &s[..]) {
-        Some("-") | None => Box::new(io::stdout()) as Box<Writer>,
-        Some(f) => Box::new(io::File::create(&Path::new(f))) as Box<Writer>,
+        Some("-") | None => Box::new(io::stdout()) as Box<Write>,
+        Some(f) => match File::create(&Path::new(f)) {
+            Ok(f) => Box::new(f) as Box<Write>,
+            Err(e) => panic!("cannot open the output {}: {}", f, e),
+        },
     };
 
     // XXX should really use the incremental interface
-    let decoded = match inenc.decode(&input.read_to_end().unwrap(), intrap) {
+    let mut ret = Vec::new();
+    input.read_to_end(&mut ret).ok().expect("cannot read from the input");
+    let decoded = match inenc.decode(&ret, intrap) {
         Ok(s) => s,
         Err(e) => panic!("decoder error: {}", e),
     };
