@@ -186,7 +186,7 @@ impl RawDecoder for UTF8Decoder {
         write_bytes(output, &input[0..processed]);
         if processed < input.len() {
             let morequeuelen = input.len() - processed;
-            for i in range(0, morequeuelen) {
+            for i in 0..morequeuelen {
                 self.queue[self.queuelen + i] = input[processed + i];
             }
             self.queuelen += morequeuelen;
@@ -345,7 +345,7 @@ mod tests {
 
     #[test]
     fn test_invalid_continuation() {
-        for c in range(0x80u8, 0xc0) {
+        for c in 0x80u8..0xc0 {
             let mut d = UTF8Encoding.raw_decoder();
             assert_feed_err!(d, [], [c], [], "");
             assert_finish_ok!(d, "");
@@ -403,7 +403,7 @@ mod tests {
 
     #[test]
     fn test_invalid_start_immediate_test_finish() {
-        for c in range(0xf5u16, 0x100) {
+        for c in 0xf5u16..0x100 {
             let c = c as u8;
             let mut d = UTF8Encoding.raw_decoder();
             assert_feed_err!(d, [], [c], [], "");
@@ -413,7 +413,7 @@ mod tests {
 
     #[test]
     fn test_invalid_start_followed_by_space() {
-        for c in range(0xf5u16, 0x100) {
+        for c in 0xf5u16..0x100 {
             let c = c as u8;
 
             let mut d = UTF8Encoding.raw_decoder();
@@ -429,7 +429,7 @@ mod tests {
 
     #[test]
     fn test_invalid_lone_start_immediate_test_finish() {
-        for c in range(0xc2u8, 0xf5) {
+        for c in 0xc2u8..0xf5 {
             let mut d = UTF8Encoding.raw_decoder();
             assert_feed_ok!(d, [], [c], ""); // wait for cont. bytes
             assert_finish_err!(d, "");
@@ -438,7 +438,7 @@ mod tests {
 
     #[test]
     fn test_invalid_lone_start_followed_by_space() {
-        for c in range(0xc2u8, 0xf5) {
+        for c in 0xc2u8..0xf5 {
             let mut d = UTF8Encoding.raw_decoder();
             assert_feed_err!(d, [], [c], [0x20], "");
             assert_finish_ok!(d, "");
@@ -452,7 +452,7 @@ mod tests {
 
     #[test]
     fn test_invalid_incomplete_three_byte_seq_followed_by_space() {
-        for b in range(0xe0u8, 0xf5) {
+        for b in 0xe0u8..0xf5 {
             let c = if b == 0xe0 || b == 0xf0 {0xa0} else {0x80};
 
             let mut d = UTF8Encoding.raw_decoder();
@@ -479,7 +479,7 @@ mod tests {
 
     #[test]
     fn test_invalid_incomplete_four_byte_seq_followed_by_space() {
-        for a in range(0xf0u8, 0xf5) {
+        for a in 0xf0u8..0xf5 {
             let b = if a == 0xf0 {0xa0} else {0x80};
             let c = 0x80;
 
